Adds a cohort template definition to an existing cohort definition set or creates one if none provided
addCohortTemplateDefintion(
cohortDefinitionSet = createEmptyCohortDefinitionSet(),
cohortTemplateDefintion
)The cohortDefinitionSet argument must be a data frame with
the following columns:
The unique integer identifier of the cohort
The cohort's name
The OHDSI-SQL used to generate the cohort
Optionally, this data frame may contain:
The Circe JSON representation of the cohort
An instance of CohortTemplateDefinition (or subclass). See [@seealso [createCohortTemplateDefinition()]].