This function retrieves the data from the cohort subset statistics table and writes them to the subset statistics folder specified in the function call.
exportCohortSubsetStatsTables(
connectionDetails,
connection = NULL,
cohortDatabaseSchema,
cohortTableNames = getCohortTableNames(),
cohortSubsetStatisticsFolder,
snakeCaseToCamelCase = TRUE,
fileNamesInSnakeCase = FALSE,
databaseId = NULL,
minCellCount = 5,
tablePrefix = ""
)An object of type connectionDetails as created using the
createConnectionDetails function in the
DatabaseConnector package. Can be left NULL if connection is
provided.
An object of type connection as created using the
connect function in the
DatabaseConnector package. Can be left NULL if connectionDetails
is provided, in which case a new connection will be opened at the start
of the function, and closed when the function finishes.
Schema name where your cohort tables reside. Note that for SQL Server, this should include both the database and schema name, for example 'scratch.dbo'.
The names of the cohort tables. See getCohortTableNames
for more details.
The path to the folder where the cohort subset statistics results will be written.
Should column names in the exported files convert from snake_case to camelCase? Default is FALSE
Should the exported files use snake_case? Default is FALSE
Optional - when specified, the databaseId will be added to the exported results
To preserve privacy: the minimum number of subjects contributing to a count before it can be included in the results. If the count is below this threshold, it will be set to `-minCellCount`.
Optional - allows to append a prefix to the exported file names.